<?php

/**
 * @file
 * Drush commands for content_synchronizer module.
 */

use Drupal\content_synchronizer\Entity\ImportEntity;
use Drupal\content_synchronizer\Processors\ExportEntityWriter;

/**
 * Implementation of hook_drush_command().
 */
function content_synchronizer_drush_command() {
  $items = [];

  $items['content-synchronizer-create-import'] = [
    'description'        => 'Create an import from passed .zip file.',
    'arguments'          => [
      'file' => 'Optional. The cache bin to fetch from.',
    ],
    'required-arguments' => 1,
    'aliases'            => ['csci'],
  ];

  $items['content-synchronizer-clean-temporary-files'] = [
    'description' => 'Delete temporary files.',
    'aliases'     => ['csctf'],
  ];

  return $items;
}

/**
 * Create an import entity from a zip file.
 *
 * @param string $path
 *   The path to the file to import.
 */
function drush_content_synchronizer_create_import($path) {
  if (file_exists($path)) {
    $extensionData = explode('.', $path);
    if (end($extensionData) == 'zip') {
      if ($file = file_save_data(file_get_contents($path))) {
        $name = strip_tags(t('Drush import - %date', [
          '%date' => \Drupal::service('date.formatter')
            ->format(time())
        ]));
        $ie = ImportEntity::create(
          [
            'name'                      => $name,
            ImportEntity::FIELD_ARCHIVE => $file
          ]
        );
        $ie->save();
      }
    }
    else {
      drush_log('The file is not a .zip archive', 'error');
    }
  }
  else {
    drush_log('No file found', 'error');
  }

}

/**
 * Delete temporary files.
 */
function drush_content_synchronizer_clean_temporary_files() {
  $path = \Drupal::service('file_system')
    ->realpath(ExportEntityWriter::GENERATOR_DIR);
  foreach (glob($path . '/*') as $file) {
    if (is_dir($file)) {
      file_unmanaged_delete_recursive($file);
    }
  }
}
